==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_entities/workorder_001/ProductionDetails.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONREQUESTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONREQUESTREVISION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONORDER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONPRIORITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONPRIORITYDESC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONSTARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONENDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACCOUNTINGENTITY" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "productionrequestcode",
    "productionrequestrevision",
    "productionorder",
    "productionpriority",
    "productionprioritydesc",
    "productionstartdate",
    "productionenddate",
    "accountingentity"
})
@XmlRootElement(name = "ProductionDetails")
public class ProductionDetails {

    @XmlElement(name = "PRODUCTIONREQUESTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String productionrequestcode;
    @XmlElement(name = "PRODUCTIONREQUESTREVISION", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY productionrequestrevision;
    @XmlElement(name = "PRODUCTIONORDER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String productionorder;
    @XmlElement(name = "PRODUCTIONPRIORITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String productionpriority;
    @XmlElement(name = "PRODUCTIONPRIORITYDESC", namespace = "http://schemas.datastream.net/MP_fields")
    protected String productionprioritydesc;
    @XmlElement(name = "PRODUCTIONSTARTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME productionstartdate;
    @XmlElement(name = "PRODUCTIONENDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME productionenddate;
    @XmlElement(name = "ACCOUNTINGENTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String accountingentity;

    /**
     * Obtient la valeur de la propriété productionrequestcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRODUCTIONREQUESTCODE() {
        return productionrequestcode;
    }

    /**
     * Définit la valeur de la propriété productionrequestcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRODUCTIONREQUESTCODE(String value) {
        this.productionrequestcode = value;
    }

    /**
     * Obtient la valeur de la propriété productionrequestrevision.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPRODUCTIONREQUESTREVISION() {
        return productionrequestrevision;
    }

    /**
     * Définit la valeur de la propriété productionrequestrevision.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPRODUCTIONREQUESTREVISION(QUANTITY value) {
        this.productionrequestrevision = value;
    }

    /**
     * Obtient la valeur de la propriété productionorder.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRODUCTIONORDER() {
        return productionorder;
    }

    /**
     * Définit la valeur de la propriété productionorder.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRODUCTIONORDER(String value) {
        this.productionorder = value;
    }

    /**
     * Obtient la valeur de la propriété productionpriority.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRODUCTIONPRIORITY() {
        return productionpriority;
    }

    /**
     * Définit la valeur de la propriété productionpriority.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRODUCTIONPRIORITY(String value) {
        this.productionpriority = value;
    }

    /**
     * Obtient la valeur de la propriété productionprioritydesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRODUCTIONPRIORITYDESC() {
        return productionprioritydesc;
    }

    /**
     * Définit la valeur de la propriété productionprioritydesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRODUCTIONPRIORITYDESC(String value) {
        this.productionprioritydesc = value;
    }

    /**
     * Obtient la valeur de la propriété productionstartdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPRODUCTIONSTARTDATE() {
        return productionstartdate;
    }

    /**
     * Définit la valeur de la propriété productionstartdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPRODUCTIONSTARTDATE(DATETIME value) {
        this.productionstartdate = value;
    }

    /**
     * Obtient la valeur de la propriété productionenddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPRODUCTIONENDDATE() {
        return productionenddate;
    }

    /**
     * Définit la valeur de la propriété productionenddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPRODUCTIONENDDATE(DATETIME value) {
        this.productionenddate = value;
    }

    /**
     * Obtient la valeur de la propriété accountingentity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACCOUNTINGENTITY() {
        return accountingentity;
    }

    /**
     * Définit la valeur de la propriété accountingentity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACCOUNTINGENTITY(String value) {
        this.accountingentity = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/workorder_001/ProductionDetails.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONREQUESTCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONREQUESTREVISION" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONORDER" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONPRIORITY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONPRIORITYDESC" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONSTARTDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONENDDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ACCOUNTINGENTITY" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "productionrequestcode",
    "productionrequestrevision",
    "productionorder",
    "productionpriority",
    "productionprioritydesc",
    "productionstartdate",
    "productionenddate",
    "accountingentity"
})
@XmlRootElement(name = "ProductionDetails")
public class ProductionDetails {

    @XmlElement(name = "PRODUCTIONREQUESTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String productionrequestcode;
    @XmlElement(name = "PRODUCTIONREQUESTREVISION", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY productionrequestrevision;
    @XmlElement(name = "PRODUCTIONORDER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String productionorder;
    @XmlElement(name = "PRODUCTIONPRIORITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String productionpriority;
    @XmlElement(name = "PRODUCTIONPRIORITYDESC", namespace = "http://schemas.datastream.net/MP_fields")
    protected String productionprioritydesc;
    @XmlElement(name = "PRODUCTIONSTARTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME productionstartdate;
    @XmlElement(name = "PRODUCTIONENDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME productionenddate;
    @XmlElement(name = "ACCOUNTINGENTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String accountingentity;

    /**
     * Gets the value of the productionrequestcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRODUCTIONREQUESTCODE() {
        return productionrequestcode;
    }

    /**
     * Sets the value of the productionrequestcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRODUCTIONREQUESTCODE(String value) {
        this.productionrequestcode = value;
    }

    /**
     * Gets the value of the productionrequestrevision property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPRODUCTIONREQUESTREVISION() {
        return productionrequestrevision;
    }

    /**
     * Sets the value of the productionrequestrevision property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPRODUCTIONREQUESTREVISION(QUANTITY value) {
        this.productionrequestrevision = value;
    }

    /**
     * Gets the value of the productionorder property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRODUCTIONORDER() {
        return productionorder;
    }

    /**
     * Sets the value of the productionorder property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRODUCTIONORDER(String value) {
        this.productionorder = value;
    }

    /**
     * Gets the value of the productionpriority property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRODUCTIONPRIORITY() {
        return productionpriority;
    }

    /**
     * Sets the value of the productionpriority property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRODUCTIONPRIORITY(String value) {
        this.productionpriority = value;
    }

    /**
     * Gets the value of the productionprioritydesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRODUCTIONPRIORITYDESC() {
        return productionprioritydesc;
    }

    /**
     * Sets the value of the productionprioritydesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRODUCTIONPRIORITYDESC(String value) {
        this.productionprioritydesc = value;
    }

    /**
     * Gets the value of the productionstartdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPRODUCTIONSTARTDATE() {
        return productionstartdate;
    }

    /**
     * Sets the value of the productionstartdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPRODUCTIONSTARTDATE(DATETIME value) {
        this.productionstartdate = value;
    }

    /**
     * Gets the value of the productionenddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPRODUCTIONENDDATE() {
        return productionenddate;
    }

    /**
     * Sets the value of the productionenddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPRODUCTIONENDDATE(DATETIME value) {
        this.productionenddate = value;
    }

    /**
     * Gets the value of the accountingentity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACCOUNTINGENTITY() {
        return accountingentity;
    }

    /**
     * Sets the value of the accountingentity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACCOUNTINGENTITY(String value) {
        this.accountingentity = value;
    }

}
